/*
    w32loader
    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __RASDLG_H__
#define __RASDLG_H__


#include "w32ldr.h"


G_BEGIN_DECLS


#include "pshpack4.h"
typedef struct _RASDIALDLG
{
  DWORD dwSize;
  HWND hwndOwner;
  DWORD dwFlags;
  LONG xDlg;
  LONG yDlg;
  DWORD dwSubEntry;
  DWORD dwError;
  ULONG_PTR reserved;
  ULONG_PTR reserved2;
} RASDIALDLG, *LPRASDIALDLG;
#include "poppack.h"


extern W32LdrExport w32ldr_rasdlg_exports[];


G_END_DECLS


#endif /* __RASDLG_H__ */
